mapAsync<R2> abstract method

Future<Either<L, R2>> mapAsync<R2>(
  1. FutureOr<R2> f(
    1. R right
    )
)

Asynchronously transforms the Right value using f, if present.

If this is a Left, the left value is returned unchanged.

Implementation

Future<Either<L, R2>> mapAsync<R2>(FutureOr<R2> Function(R right) f);