flatMapAsync<R2> method

  1. @override
Future<Either<L, R2>> flatMapAsync<R2>(
  1. FutureOr<Either<L, R2>> f(
    1. R right
    )
)
override

Asynchronously applies f to the Right value, if present.

If this is a Left, the left value is returned unchanged.

Implementation

@override
Future<Either<L, R2>> flatMapAsync<R2>(
  FutureOr<Either<L, R2>> Function(R right) f,
) async {
  return Left<L, R2>(value);
}