mapAsync<R2> method
Asynchronously transforms the Right value using f, if present.
If this is a Left, the left value is returned unchanged.
Implementation
@override
Future<Either<L, R2>> mapAsync<R2>(FutureOr<R2> Function(R right) f) async {
return Left<L, R2>(value);
}