getLeft method
Throws a StateError because this is a Right and does not contain a Left value.
Use getRight if you expect the right value.
Implementation
@override
L getLeft() {
throw StateError('Cannot get a Left value from $this.');
}
Throws a StateError because this is a Right and does not contain a Left value.
Use getRight if you expect the right value.
@override
L getLeft() {
throw StateError('Cannot get a Left value from $this.');
}