mapAsync<R2> method

  1. @override
Future<Either<L, R2>> mapAsync<R2>(
  1. FutureOr<R2> f(
    1. R right
    )
)
override

Asynchronously transforms the Right value using f, if present.

If this is a Left, the left value is returned unchanged.

Implementation

@override
Future<Either<L, R2>> mapAsync<R2>(FutureOr<R2> Function(R right) f) async {
  return Right<L, R2>(await f(value));
}