StreamEither<T> typedef

StreamEither<T> = Stream<Either<Failure, T>>

A type alias for a Stream that emits fallible values.

Used for streaming operations that can emit successful values or failures.

Implementation

typedef StreamEither<T> = Stream<Either<Failure, T>>;