A contract for defining streaming use cases.
Use this when a use case emits multiple values over time and each emission can independently succeed or fail.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
Params params) → StreamEither< SuccessType> -
Executes the use case with the given
paramsand returns a StreamEither result. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited