call abstract method
Executes the use case with the given params and returns a StreamEither result.
Implementation
StreamEither<SuccessType> call(Params params);
Executes the use case with the given params and returns a StreamEither result.
StreamEither<SuccessType> call(Params params);