isPositive property
bool
get
isPositive
Returns true if this duration is greater than zero.
Implementation
bool get isPositive => inMicroseconds > 0;
Returns true if this duration is greater than zero.
bool get isPositive => inMicroseconds > 0;