minutesPart property
int
get
minutesPart
Returns the absolute minutes component of the duration (0-59).
Implementation
int get minutesPart => (inMinutes % 60).abs();
Returns the absolute minutes component of the duration (0-59).
int get minutesPart => (inMinutes % 60).abs();