PasswordStrength class

Represents the strength grading of a given password.

Constructors

PasswordStrength({required bool hasMinLength, required bool hasUppercase, required bool hasLowercase, required bool hasDigit, required bool hasSpecial})
Constructs a PasswordStrength instance.
const

Properties

hasDigit bool
Whether the password contains at least one digit.
final
hashCode int
The hash code for this object.
no setterinherited
hasLowercase bool
Whether the password contains at least one lowercase letter.
final
hasMinLength bool
Whether the password meets the minimum length requirement.
final
hasSpecial bool
Whether the password contains at least one special character.
final
hasUppercase bool
Whether the password contains at least one uppercase letter.
final
isStrong bool
Returns true if all password strength criterion are satisfied.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score int
0–5 score, useful for a strength indicator bar.
no setter
unmetRequirements List<String>
Returns a list of strings detailing which requirements have not yet been met.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited