isBlank property
bool
get
isBlank
Checks if the string is empty or contains only whitespace.
Implementation
bool get isBlank => trim().isEmpty;
Checks if the string is empty or contains only whitespace.
bool get isBlank => trim().isEmpty;