isNotBlank property
bool
get
isNotBlank
Checks if the string contains at least one non-whitespace character.
Implementation
bool get isNotBlank => trim().isNotEmpty;
Checks if the string contains at least one non-whitespace character.
bool get isNotBlank => trim().isNotEmpty;