compact method

Iterable<T> compact()

Shorthand for compactMap when you only want to strip nulls with no transformation — just whereNotNull as a method call for symmetry with compactMap.

Implementation

Iterable<T> compact() => whereNotNull;