isNullOrBlank property
bool
get
isNullOrBlank
Returns true if the string is null or entirely whitespace.
Implementation
bool get isNullOrBlank => this == null || this!.trim().isEmpty;
Returns true if the string is null or entirely whitespace.
bool get isNullOrBlank => this == null || this!.trim().isEmpty;