isBlank property
bool
get
isBlank
Returns true if the string is purely whitespace or empty.
Implementation
bool get isBlank => trim().isEmpty;
Returns true if the string is purely whitespace or empty.
bool get isBlank => trim().isEmpty;