isNumeric property
bool
get
isNumeric
Returns true if the string represents a valid number.
Implementation
bool get isNumeric => double.tryParse(this) != null;
Returns true if the string represents a valid number.
bool get isNumeric => double.tryParse(this) != null;