EmailEmptyIssue class final
Email input is empty after trimming.
- Inheritance
-
- Object
- ValidationIssue
- EmailValidationIssue
- EmailEmptyIssue
Constructors
- EmailEmptyIssue()
-
Creates an empty-email issue.
const
Properties
- code → String
-
Machine-readable issue code.
no setteroverride
- defaultMessage → String
-
Default English message.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited