PasswordTooLongIssue class final

Password is longer than allowed.

Inheritance

Constructors

PasswordTooLongIssue({required int currentLength, required int maxLength})
Creates a too-long issue.
const

Properties

code String
Machine-readable issue code.
no setteroverride
currentLength int
The provided password length.
final
hashCode int
The hash code for this object.
no setterinherited
maxLength int
The configured maximum length.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited