TextTooLongIssue class final

Text is longer than allowed.

Inheritance

Constructors

TextTooLongIssue({required int currentLength, required int maxLength})
Creates a too-long issue.
const

Properties

code String
Machine-readable issue code.
no setteroverride
currentLength int
The provided input length.
final
defaultMessage String
Default English message.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
maxLength int
The configured maximum length.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited