regex/digit_reg library

Properties

digitReg RegExp
A RegExp object used to validate if a string consists entirely of digits.
getter/setter pair
digitRegStr String
A regular expression pattern that matches strings containing only digits.
getter/setter pair