intReg top-level property

RegExp intReg
getter/setter pair

This file contains a regular expression to match ASCII characters. A regular expression that matches any string containing only ASCII characters. The pattern used by the asciiReg regular expression.

Implementation

RegExp intReg = RegExp(intRegStr);