IdGenerator class

Public API for generating various types of IDs and encodings.

Constructors

IdGenerator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

encodeToBase64(List<Object?> objects) String
Encodes a list of objects to a Base64 string.
nanoid({int size = 21}) String
Generates a nanoid-style random ID.
randomString({int length = 8, bool useLetters = true, bool useNumbers = true, bool useSymbols = true}) String
Generates a random string with configurable character sets.
timestampId() String
Generates a timestamp-based ID with prefix 'G'.
uuidV1() String
Generates a UUID v1-like random ID.