asciiRegStr top-level property
The pattern used by the asciiReg regular expression. The pattern matches any string that contains only ASCII characters (0-127).
Implementation
String asciiRegStr = r'^[\x00-\x7F]+$';
The pattern used by the asciiReg regular expression. The pattern matches any string that contains only ASCII characters (0-127).
String asciiRegStr = r'^[\x00-\x7F]+$';