lowerCaseReg top-level property
A RegExp object used to validate if a string contains only lowercase letters.
Uses the lowerCaseReg pattern to perform the match.
Implementation
RegExp lowerCaseReg = RegExp(lowerCaseRegStr);
A RegExp object used to validate if a string contains only lowercase letters.
Uses the lowerCaseReg pattern to perform the match.
RegExp lowerCaseReg = RegExp(lowerCaseRegStr);