phoneReg top-level property
A RegExp object used to validate phone numbers using phoneRegStr.
Use this to check whether a given string matches common international phone number formats.
Implementation
RegExp phoneReg = RegExp(phoneRegStr);
A RegExp object used to validate phone numbers using phoneRegStr.
Use this to check whether a given string matches common international phone number formats.
RegExp phoneReg = RegExp(phoneRegStr);