specialCharReg top-level property
A RegExp object used to check if a string contains only special characters.
Uses the specialCharReg pattern to perform the match.
Implementation
RegExp specialCharReg = RegExp(specialCharStr);
A RegExp object used to check if a string contains only special characters.
Uses the specialCharReg pattern to perform the match.
RegExp specialCharReg = RegExp(specialCharStr);