upperCaseReg top-level property
A RegExp object used to validate if a string contains only uppercase letters.
Uses the upperCaseReg pattern to perform the match.
Implementation
RegExp upperCaseReg = RegExp(upperCaseStr);
A RegExp object used to validate if a string contains only uppercase letters.
Uses the upperCaseReg pattern to perform the match.
RegExp upperCaseReg = RegExp(upperCaseStr);