whiteSpaceReg top-level property
A RegExp object used to validate if a string contains only whitespace characters.
Uses the whiteSpaceStr pattern to check for strings that include only spaces, tabs, or line breaks.
Implementation
RegExp whiteSpaceReg = RegExp(whiteSpaceStr);