NumberTooLargeIssue class final
Number is larger than the allowed maximum.
- Inheritance
-
- Object
- ValidationIssue
- NumberValidationIssue
- NumberTooLargeIssue
Constructors
- NumberTooLargeIssue({required num currentValue, required num maxValue})
-
const
Properties
- code → String
-
Machine-readable issue code.
no setteroverride
- currentValue → num
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxValue → num
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited