NumberTooSmallIssue class final

Number is smaller than the allowed minimum.

Inheritance

Constructors

NumberTooSmallIssue({required num currentValue, required num minValue})
const

Properties

code String
Machine-readable issue code.
no setteroverride
currentValue num
final
hashCode int
The hash code for this object.
no setterinherited
minValue num
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited