NumberValidationConfig class final

Configuration for number validation.

Constructors

NumberValidationConfig({num? min, num? max, bool allowNegative = true, bool integerOnly = false, int? maxDecimalPlaces})
Creates a number validation config.
const
NumberValidationConfig.positiveInteger({num? min, num? max})
Preset for positive integers.
factory

Properties

allowNegative bool
Whether negative values are allowed.
final
hashCode int
The hash code for this object.
no setterinherited
integerOnly bool
Whether only whole numbers are allowed.
final
max num?
Maximum allowed value.
final
maxDecimalPlaces int?
Maximum allowed decimal places.
final
min num?
Minimum allowed value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited