NumberValidator class final
Canonical validator for number inputs.
Constructors
- NumberValidator([NumberValidationConfig config = const NumberValidationConfig()])
-
Creates a number validator.
const
Properties
- config → NumberValidationConfig
-
Rules used during validation.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
String input) → ValidationResult< NumberValidationIssue, num> - Validates and parses a number.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited