PasswordTooShortIssue class final
Password is shorter than allowed.
- Inheritance
-
- Object
- ValidationIssue
- PasswordValidationIssue
- PasswordTooShortIssue
Constructors
- PasswordTooShortIssue({required int currentLength, required int minLength})
-
const
Properties
- code → String
-
Machine-readable issue code.
no setteroverride
- currentLength → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- minLength → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited