TextInvalidCharactersIssue class final
Text includes disallowed characters.
- Inheritance
-
- Object
- ValidationIssue
- TextValidationIssue
- TextInvalidCharactersIssue
Constructors
- TextInvalidCharactersIssue(String invalidCharacters)
-
const
Properties
- code → String
-
Machine-readable issue code.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- invalidCharacters → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited