TextValidator class final

Canonical validator for generic text inputs.

Constructors

TextValidator([TextValidationConfig config = const TextValidationConfig()])
Creates a text validator.
const

Properties

config TextValidationConfig
Rules used during validation.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate(String input) ValidationResult<TextValidationIssue, String>
Validates and optionally normalizes a text value.

Operators

operator ==(Object other) bool
The equality operator.
inherited