ValidationIssue class abstract

Base contract for typed validation failures.

Implementers

Constructors

ValidationIssue()
Creates a validation issue.
const

Properties

code String
Machine-readable issue code.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited