GSpacing class abstract
Default spacing constants for UI layout systems.
Constructors
- GSpacing()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- lg → const double
- Large spacing.
- md → const double
- Medium spacing.
- sm → const double
- Small spacing.
- spaceUnit → const double
- The default unit of spacing.
- xlg → const double
- Extra large spacing.
- xs → const double
- Extra small spacing.
- xxlg → const double
- Extra-extra large spacing.
- xxs → const double
- Extra-extra small spacing.
- xxxlg → const double
- Extra-extra-extra large spacing.
- xxxs → const double
- Extra-extra-extra small spacing.