flatMapAsync<R2> abstract method
Asynchronously applies f to the Right value, if present.
If this is a Left, the left value is returned unchanged.
Implementation
Future<Either<L, R2>> flatMapAsync<R2>(
FutureOr<Either<L, R2>> Function(R right) f,
);