mapAsync<R2> abstract method
Asynchronously transforms the Right value using f, if present.
If this is a Left, the left value is returned unchanged.
Implementation
Future<Either<L, R2>> mapAsync<R2>(FutureOr<R2> Function(R right) f);