Failure class
Represents a failure in an operation, usually as the Left value of an Either.
Contains a human-readable error message, optional machine-readable code, and optional structured details.
Constructors
Properties
- code → String?
-
An optional stable code for programmatic error handling.
final
- details → GMap
-
Optional structured metadata describing the failure.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- message → String
-
The error message describing the failure.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override