functional library
Re-exports functional programming primitives from gmana_functional.
Classes
-
Either<
L, R> - A generic type that represents a value of one of two possible types (a disjoint union).
- Failure
-
Represents a failure in an operation, usually as the
Leftvalue of an Either. -
Left<
L, R> - Represents the failure or error side of an Either.
- NoParams
- A class that represents a lack of parameters.
-
Right<
L, R> -
A concrete implementation of Either that represents the successful value (
Right) in a computation. -
StreamUseCase<
SuccessType, Params> - A contract for defining streaming use cases.
- Unit
- Represents a void-like value in functional programming.
-
UseCase<
SuccessType, Params> - A contract for defining use cases (application business logic) in a clean architecture approach.
Constants
Typedefs
-
FutureResult<
T> = Future< Result< T> > - A future that completes with a fallible Result.
-
FutureResultUnit
= FutureResult<
Unit> - A FutureResult for operations that return no meaningful success value.
-
Result<
T> = Either< Failure, T> -
A standard fallible result with Failure on the left and
Ton the right. -
ResultUnit
= Result<
Unit> - A Result for operations that return no meaningful success value.
-
StreamResult<
T> = Stream< Result< T> > - A stream that emits fallible Result values.
-
StreamResultUnit
= StreamResult<
Unit> - A StreamResult for streams that emit no meaningful success value.