functional
library
Classes
-
Either<L, R>
-
A generic type that represents a value of one of two possible types (a disjoint union).
-
Failure
-
Represents a failure in an operation, usually as the
Left value of an Either.
-
Left<L, R>
-
Represents the failure or error side of an Either.
-
NoParams
-
A class that represents a lack of parameters.
-
Right<L, R>
-
A concrete implementation of Either that represents the successful value (
Right) in a computation.
-
Unit
-
Represents a void-like value in functional programming.
-
UseCase<SuccessType, Params>
-
A contract for defining use cases (application business logic) in a clean architecture approach.
Constants
-
unit
→ const Unit
-
A singleton instance representing a unit of work with no meaningful value.