Throttler class
A small utility to throttle function execution.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- milliseconds → int
-
Throttle delay in milliseconds.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void - Cancels the active throttle window.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
void action()) → void -
Runs
actionimmediately if not currently throttled. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited