IdGeneratorUtils class
Utility class for ID generation helper methods.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
generateBits(
Random random, int bitCount, int digitCount) → String - Generates random bits and formats them as a hexadecimal string.
-
generateRandomString(
{required int length, required String characters, required Random random}) → String -
Generates a random string from the provided
characters. -
printDigits(
int value, int count) → String - Formats a value as a hexadecimal string.