This file contains a regular expression to match ASCII characters.
A regular expression that matches any string containing only ASCII characters.
The pattern used by the asciiReg regular expression.
This file contains a regular expression to match ASCII characters.
A regular expression that matches any string containing only ASCII characters.
The pattern used by the asciiReg regular expression.
This file contains a regular expression to match ASCII characters.
A regular expression that matches any string containing only ASCII characters.
The pattern used by the asciiReg regular expression.
The pattern used by the floatReg regular expression.
The pattern matches any string that contains a valid floating-point number.
The pattern allows for optional leading and trailing digits, an optional decimal point,
This file contains a regular expression to match ASCII characters.
A regular expression that matches any string containing only ASCII characters.
The pattern used by the asciiReg regular expression.
The pattern matches any string that contains only characters in the range 0-127 (inclusive).
The pattern used by the fourDigit regular expression.
The pattern matches any string that contains exactly 4 digits (0-9).
The pattern allows for optional leading and trailing digits, an optional decimal point,
This file contains a regular expression to match ASCII characters.
A regular expression that matches any string containing only ASCII characters.
The pattern used by the asciiReg regular expression.
The pattern used by the fullWidthReg regular expression.
The pattern matches any string that contains only full-width characters.
The pattern allows for optional leading and trailing digits, an optional decimal point,
This file contains a regular expression to match ASCII characters.
A regular expression that matches any string containing only ASCII characters.
The pattern used by the asciiReg regular expression.
The pattern matches any string that contains only characters in the range 0-127 (inclusive).
The pattern used by the halfWidthReg regular expression.
The pattern matches any string that contains only half-width characters.
The pattern allows for optional leading and trailing digits, an optional decimal point,
and an optional exponent part (e.g., e+10 or E-10).
The pattern matches any string that contains only half-width characters.
This file contains a regular expression to match ASCII characters.
A regular expression that matches any string containing only ASCII characters.
The pattern used by the asciiReg regular expression.
The pattern matches any string that contains only characters in the range 0-127 (inclusive).
The pattern used by the hexadecimalReg regular expression.
The pattern matches any string that contains only hexadecimal digits (0-9, a-f, A-F).
The pattern allows for an optional leading and trailing digits, an optional decimal point,
and an optional exponent part (e.g., e+10 or E-10).
This file contains a regular expression to match ASCII characters.
A regular expression that matches any string containing only ASCII characters.
The pattern used by the asciiReg regular expression.
The pattern matches any string that contains only characters in the range 0-127 (inclusive).
This file contains a regular expression to match ASCII characters.
A regular expression that matches any string containing only ASCII characters.
The pattern used by the asciiReg regular expression.
The pattern used by the intReg regular expression.
The pattern matches any string that contains a valid integer.
The pattern allows for optional leading and trailing digits, an optional decimal point,
and an optional exponent part (e.g., e+10 or E-10).
The pattern matches any string that contains only digits (0-9).
This file contains a regular expression to match ASCII characters.
A regular expression that matches any string containing only ASCII characters.
The pattern used by the asciiReg regular expression.
The pattern matches any string that contains only characters in the range 0-127 (inclusive).
The pattern used by the ipv4Maybe regular expression.
The pattern matches any string that contains a valid IPv4 address.
The pattern allows for optional leading and trailing digits, an optional decimal point,
and an optional exponent part (e.g., e+10 or E-10).
This file contains a regular expression to match ASCII characters.
A regular expression that matches any string containing only ASCII characters.
The pattern used by the asciiReg regular expression.
The pattern matches any string that contains only characters in the range 0-127 (inclusive).
The pattern used by the ipv6 regular expression.
The pattern matches any string that contains a valid IPv6 address.
The pattern allows for optional leading and trailing digits, an optional decimal point,
and an optional exponent part (e.g., e+10 or E-10).
The pattern matches any string that contains only hexadecimal digits (0-9, a-f, A-F).