whiteSpaceStr top-level property
A regular expression pattern that matches strings containing only whitespace characters.
This pattern ensures the string consists entirely of one or more whitespace characters such as spaces, tabs, or newlines. It will not match an empty string.
Implementation
String whiteSpaceStr = r'^\s+$';