EmailValidationConfig class final
Configuration for email validation.
Constructors
-
EmailValidationConfig({int maxLength = 254, int maxLocalPartLength = 64, int maxDomainLength = 253, Set<
String> disposableDomains = _defaultDisposableDomains, Set<String> blockedDomains = const {}, bool allowDisposable = true}) -
Creates an email validation config.
const
- EmailValidationConfig.strict()
-
A stricter preset that rejects disposable domains.
factory
Properties
- allowDisposable → bool
-
Whether disposable domains are allowed.
final
-
blockedDomains
→ Set<
String> -
Explicitly blocked domains.
final
-
disposableDomains
→ Set<
String> -
Known disposable domains.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxDomainLength → int
-
Maximum allowed domain length.
final
- maxLength → int
-
Maximum allowed email length.
final
- maxLocalPartLength → int
-
Maximum allowed local-part length.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited