EmailValidator class final
Canonical validator for email inputs.
Constructors
- EmailValidator([EmailValidationConfig config = const EmailValidationConfig()])
-
Creates an email validator.
const
Properties
- config → EmailValidationConfig
-
Rules used during validation.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
String input) → ValidationResult< EmailValidationIssue, String> - Validates and normalizes an email.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited