UsernameValidator class
Provides validation rules and utilities for validating usernames.
This class includes both a getRules() method to return a list of validation rules,
and a validate() method to run all validation checks on a given username string.
Common username constraints include:
- Required field
- Minimum and maximum length
- Forbidden characters (e.g.,
@) - Optional pattern for allowed characters
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getRules(
{int minLength = 3, int maxLength = 20, Set< String> forbiddenCharacters = const {'@'}, RegExp? allowedPattern}) → List<ValidationRule> - Returns a list of ValidationRules used to validate a username.
-
validate(
String? value, {int minLength = 3, int maxLength = 20, Set< String> forbiddenCharacters = const {'@'}, RegExp? allowedPattern}) → String? -
Validates a given
value(username) using the defined rules.